[U-Boot-Users] [PATCH 5/5][RESEND] CSB 637 board support

Anders Larsen alarsen at rea.de
Wed Oct 5 18:50:15 CEST 2005


Wolfgang Denk <wd at denx.de> schreibt:
>Previously checked in, please verify.

Hi Wolfgang,

the updated (unapplied) patch from 2005-08-24 sets the machine-id
correctly (the original version erroneously used the id of the
at91rm9200dk board).

Hoping that the stoopid MUA I'm forced to use doesn't treat it too badly:

Cheers
 Anders

Signed-off-by: Anders Larsen <alarsen at rea.de>

CHANGELOG:
  Patch by Anders Larsen <alarsen at rea.de>, 2005-10-05
  Fix the machine-id of the Cogent csb637 board

---

 README                   |   14 +++++++-------
 board/csb637/csb637.c    |    4 ++--
 include/configs/csb637.h |    3 ++-
 3 files changed, 11 insertions(+), 10 deletions(-)

diff --git a/README b/README
--- a/README
+++ b/README
@@ -303,13 +303,13 @@ The following options need to be configu
 		-----------------
 
 		CONFIG_ARMADILLO,	CONFIG_AT91RM9200DK,	CONFIG_CERF250,
-		CONFIG_DNP1110, 	CONFIG_EP7312,		CONFIG_H2_OMAP1610,
-		CONFIG_HHP_CRADLE,	CONFIG_IMPA7,		CONFIG_INNOVATOROMAP1510,
-		CONFIG_INNOVATOROMAP1610, CONFIG_KB9202,	CONFIG_LART,
-		CONFIG_LPD7A400,	CONFIG_LUBBOCK,		CONFIG_OSK_OMAP5912,
-		CONFIG_OMAP2420H4,	CONFIG_SHANNON,		CONFIG_P2_OMAP730,
-		CONFIG_SMDK2400,	CONFIG_SMDK2410,	CONFIG_TRAB,
-		CONFIG_VCMA9
+		CONFIG_CSB637,		CONFIG_DNP1110, 	CONFIG_EP7312,
+		CONFIG_H2_OMAP1610,	CONFIG_HHP_CRADLE,	CONFIG_IMPA7,
+		CONFIG_INNOVATOROMAP1510, CONFIG_INNOVATOROMAP1610, CONFIG_KB9202,
+		CONFIG_LART,		CONFIG_LPD7A400,	CONFIG_LUBBOCK,
+		CONFIG_OSK_OMAP5912,	CONFIG_OMAP2420H4,	CONFIG_SHANNON,
+		CONFIG_P2_OMAP730,	CONFIG_SMDK2400,	CONFIG_SMDK2410,
+		CONFIG_TRAB,		CONFIG_VCMA9
 
 		MicroBlaze based boards:
 		------------------------
diff --git a/include/configs/csb637.h b/include/configs/csb637.h
--- a/include/configs/csb637.h
+++ b/include/configs/csb637.h
@@ -34,6 +34,7 @@
 
 #define CONFIG_ARM920T		1	/* This is an ARM920T Core	*/
 #define CONFIG_AT91RM9200	1	/* It's an Atmel AT91RM9200 SoC	*/
+#define CONFIG_CSB637		1	/* on a CSB637 board		*/
 #undef  CONFIG_USE_IRQ			/* we don't need IRQ/FIQ stuff	*/
 #define USE_920T_MMU		1
 
@@ -78,7 +79,7 @@
 #define CFG_MALLOC_LEN	(CFG_ENV_SIZE + 128*1024)
 #define CFG_GBL_DATA_SIZE	128	/* size in bytes reserved for initial data */
 
-#define CONFIG_BAUDRATE 38400
+#define CONFIG_BAUDRATE 115200
 
 #define CFG_AT91C_BRGR_DIVISOR	75	/* hardcode so no __divsi3 : AT91C_MASTER_CLOCK / baudrate / 16 */
 





More information about the U-Boot mailing list
diff --git a/board/csb637/csb637.c b/board/csb637/csb637.c
--- a/board/csb637/csb637.c
+++ b/board/csb637/csb637.c
@@ -41,8 +41,8 @@ int board_init (void)
 	/* memory and cpu-speed are setup before relocation */
 	/* so we do _nothing_ here */
 
-	/* arch number of AT91RM9200DK-Board */
-	gd->bd->bi_arch_number = MACH_TYPE_AT91RM9200;
+	/* arch number of CSB637-Board */
+	gd->bd->bi_arch_number = MACH_TYPE_CSB637;
 	/* adress of boot parameters */
 	gd->bd->bi_boot_params = PHYS_SDRAM + 0x100;
 